@@ -1,8 +1,8 @@
 plotFeatureHeatmap <- function (
-x, alpha.index=NULL, stat=c("freq","coef"), feature.all = F, feature.pval.thres = NULL, feature.set = NULL,
-feature.top.n = 25, signif.code = T, xlab=NULL, ylab=NULL, main=NULL, col.main="black", cex.main=0.95,
-line=1, col=NULL, breaks=NULL, scale="none", Rowv=F, Colv=F, na.color=NULL,
-cexRow = NULL, srtRow=0, cexCol=0.75, srtCol=45, margins=c(5,5), key=T, key.title=NA, dendogram="none",
+x, alpha.index=NULL, stat=c("freq","coef"), feature.all = FALSE, feature.pval.thres = NULL, feature.set = NULL,
+feature.top.n = 25, signif.code = TRUE, xlab=NULL, ylab=NULL, main=NULL, col.main="black", cex.main=0.95,
+line=1, col=NULL, breaks=NULL, scale="none", Rowv=FALSE, Colv=FALSE, na.color=NULL,
+cexRow = NULL, srtRow=0, cexCol=0.75, srtCol=45, margins=c(5,5), key=TRUE, key.title=NA, dendogram="none",
 trace="none", notecol.freq = "black", notecol.coef = "white", notecex = 1, subtitle1=NULL, col.subtitle1="black",
 line.subtitle1=-1,cex.subtitle1=0.65, subtitle2=NULL, col.subtitle2="darkgray",line.subtitle2=-2,cex.subtitle2=0.55,
 ...) {
